/*
 * Instance.h
 * 
 * Copyright (C) 2008 Matthias Schiffer <matthias@gamezock.de>
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ZOOMEDIT_INSTANCE_H_
#define ZOOMEDIT_INSTANCE_H_

#include <gtkmm/main.h>
#include <libglademm/xml.h>
#include <libxml++/parsers/domparser.h>

namespace ZoomEdit {

namespace Gui {
class Window;
}

namespace Data {
class Level;
}

namespace View {
class TopView;
class MapView;
}

class Instance {
  public:
    virtual ~Instance();
    
    void createLevel();
    bool loadLevel(const Glib::ustring &file);
    bool saveLevel(const Glib::ustring &file);
    
    static bool create(const Glib::ustring &file = Glib::ustring());
    
  private:
    static guint instances;
    
    Glib::RefPtr<Gnome::Glade::Xml> xml;
    Gui::Window *window;
    
    xmlpp::DomParser *levelXml;
    Data::Level *level;
    
    View::TopView *view;
    View::MapView *mapView;
    
    Instance(const Glib::ustring &file);
    
    void destroy();
    
    // Prevent shallow copy
    Instance(const Instance &o);
    Instance& operator=(const Instance &o);
};

}

#endif /*ZOOMEDIT_INSTANCE_H_*/
